##############################################################################
#
# Git Aliases
#
##############################################################################
if command_exists git; then
    git config --global user.signingkey 0E669F3125C0EDB2C8B040E49D7B2F1E705D7EFC
    git config --global commit.gpgsign true

    git config --global alias.a add
    git config --global alias.b branch
    git config --global alias.c checkout
    git config --global alias.co commit
    git config --global alias.d difftool
    git config --global alias.f fetch
    git config --global alias.l log
    git config --global alias.ps push
    git config --global alias.s "status -uno"
    git config --global alias.st stash
    git config --global alias.cp cherry-pick
    git config --global alias.w switch
    git config --global alias.pm "checkout alexmatevish-master"

    git config --global alias.bn "rev-parse --abbrev-ref HEAD"  # branch-name
    git config --global alias.psc "push origin \`git rev-parse --abbrev-ref HEAD\`"  # push current
    git config --global alias.plc "pull origin \`git rev-parse --abbrev-ref HEAD\`"  # pull current
    git config --global alias.lco "log -n 1 --pretty=format:'%h'"
    git config --global alias.bp "merge-base --octopus master"
    git config --global alias.mod "!git status -s | grep -r '.*\.scala' | cut -f4 -d' '"
    
    git config --global alias.lp "log --pretty=format:\"%h%x09%an%x09%ad%x09%s\""

    alias g='git'
    alias gs='git s'
    alias gps='git push origin `git rev-parse --abbrev-ref HEAD`'
    alias gpl='git pull origin `git rev-parse --abbrev-ref HEAD`'
    alias gp='git pull origin `git rev-parse --abbrev-ref HEAD`'
    alias gdm='git diff `git bp`...HEAD'

    if command_exists meld; then

	git config --global diff.tool meld
	git config --global merge.tool meld
	git config --global --add difftool.prompt false
    fi;

    function git-delete-merged () {
        n=$'\n'
        branches=$(git branch --merged $1 | egrep -v "(^\*|master|dev)");
        if prompt_user "The following branches would be deleted:$n$branches$n"; then
            git branch --merged $1 | egrep -v "(^\*|master|dev)" | xargs git branch --delete;
        fi
    }
    alias gbdm='git-delete-merged'
    alias glatest='git checkout master && git pull'

    function wip () {
	NL=$'\n'
        GIT_ROOT=`git rev-parse --show-toplevel`
        LAST_MESSAGE=`git log -1 --pretty=%B | cat`
        if [[ $LAST_MESSAGE == "WIP"* ]]; then
            if prompt_user "Reset HEAD~? (Previous message: $LAST_MESSAGE)"; then
                git reset HEAD~;
            fi
        else
            CHANGED_FILES=`git diff --name-only HEAD $GIT_ROOT`
            if prompt_user "Commit the following files to a WIP commit? ${NL}$CHANGED_FILES${NL}"; then
                git add $GIT_ROOT && git commit -m WIP;
            fi

        fi
    }
    alias gd='yes | g d HEAD'
fi

